==> 0.4.2.tar.gz: lib/material_x.dart <==
library material_x;

export 'package:flutter/material.dart';
export 'src/AppBar/AppBar.dart';
export 'src/Button/material_button.dart';
export 'src/Button/two_button.dart';
export 'src/Card/Card.dart';
export 'src/Card/CardTile.dart';
export 'src/Card/GradientCard.dart';
export 'src/Card/StaticCard.dart';
export 'src/Container/Container.dart';
export 'src/Container/GradientContainer.dart';
export 'src/Drawer/DrawerMXFullWidth.dart';
export 'src/Drawer/rounded_drawer.dart';
export 'src/ListTile/MxListTile.dart';
export 'src/Modules/BlogTile.dart';
export 'src/Modules/BuilderStories.dart';
export 'src/Modules/CardListTile.dart';
export 'src/Modules/CardListTileGradient.dart';
export 'src/Modules/CircleView.dart';
export 'src/Modules/CrownTile.dart';
export 'src/Modules/DrawerMXuserProfile.dart';
export 'src/Modules/ExpansionTile.dart';
export 'src/Modules/List.dart';
export 'src/Modules/MxAnimationType.dart';
export 'src/Modules/ProgressLoading.dart';
export 'src/Modules/Route.dart';
export 'src/Modules/SizeTransition.dart';
export 'src/Modules/StoriesBar.dart';
export 'src/Modules/Widget.dart';
export 'src/Modules/title.dart';
export 'src/Swipper/Swipe_To.dart';
export 'src/Text/h_tag.dart';
export 'src/Text/text_material.dart';
export 'src/TextFiled/textFiled_material.dart';
export 'src/Modules/stful_stless.dart';
export 'src/Modules/space.dart';
export 'src/Modules/CardBarButton.dart';
export 'src/Heading/GradientTitle.dart';
export 'src/Heading/heading.dart';
export 'src/Heading/Title.dart';
export 'src/Modules/ImageBlue.dart';
export 'src/Responsive/Responsive_grid.dart';
export 'src/Card/CardTile.dart';
export 'src/Card/CardTiles.dart';
export 'src/Responsive/Extension.dart';
export 'src/Modules/Decoration_Image_Network.dart';
export 'src/Context/Responsive_Context.dart';
export 'src/Context/Responsive_Context.dart';
export 'src/Modules/Decoration_Image_Asset.dart';
export 'src/Modules/Decoration_Image_File.dart';
export 'src/Container/Container_Extesnstion.dart';
export 'src/Extension/Image.dart';
export 'src/Extension/Gesture.dart';
export 'src/Extension/Floating_extend.dart';
export 'src/Extension/SnackBar.dart';
export 'src/Extension/InkWell.dart';
export 'src/Extension/Column.dart';
export 'src/Extension/Row.dart';
export 'src/Extension/String.dart';
export 'src/Extension/Widget_String.dart';
export 'src/Extension/Padding.dart';
export 'src/Context/size.dart';
export 'src/Context/Transparent.dart';
export 'src/Modules/TransactioTile.dart';
export 'src/Modules/editor.dart';
export 'src/Modules/BanTile.dart';
export 'src/Extension/Widget.dart';
export 'src/Extension/BlogTile.dart';
export 'src/Extension/Shape.dart';
export 'src/Extension/LinerGradient.dart';
export 'src/Extension/Icon.dart';
export 'src/Extension/Flexable_Responsive.dart';
export 'src/Extension/Color.dart';
export 'src/Extension/function.dart';
export 'src/Extension/GridAnimated.dart';
export 'src/Extension/SilverList.dart';
export 'src/Auto_animated/animate_if_visible.dart';
export 'src/Auto_animated/grid.dart';
export 'src/Auto_animated/helpers/callbacks.dart';
export 'src/Auto_animated/helpers/options.dart';
export 'src/Auto_animated/icon_button.dart';
export 'src/Auto_animated/list.dart';
export 'src/Auto_animated/sliver_grid.dart';
export 'src/Auto_animated/sliver_list.dart';
export 'src/Modules/utils.dart';
export 'src/Extension/Scaffold.dart';
export 'src/Animations/main.dart';
export 'src/Extension/Widgets.dart';
export 'src/Widget/DropDown.dart';
export 'src/Modules/expand.dart';
export 'src/Extension/Tabbar.dart';
export 'src/Extension/Stack.dart';
export 'src/Extension/Stack.dart';
export 'src/Modules/Column.dart';
export 'src/Modules/Row.dart';
export 'src/Modules/ListView.dart';
export 'src/Modules/Stack.dart';
export 'src/Extension/Dropdown.dart';

==> 0.4.5.tar.gz: lib/material_x.dart <==
library material_x;

export 'package:flutter/material.dart';
export 'src/AppBar/AppBar.dart';
export 'src/Button/material_button.dart';
export 'src/Button/two_button.dart';
export 'src/Card/Card.dart';
export 'src/Card/CardTile.dart';
export 'src/Card/GradientCard.dart';
export 'src/Card/StaticCard.dart';
export 'src/Container/Container.dart';
export 'src/Container/GradientContainer.dart';
export 'src/Drawer/DrawerMXFullWidth.dart';
export 'src/Drawer/rounded_drawer.dart';
export 'src/ListTile/MxListTile.dart';
export 'src/Modules/BlogTile.dart';
export 'src/Modules/BuilderStories.dart';
export 'src/Modules/CardListTile.dart';
export 'src/Modules/CardListTileGradient.dart';
export 'src/Modules/CircleView.dart';
export 'src/Modules/CrownTile.dart';
export 'src/Modules/DrawerMXuserProfile.dart';
export 'src/Modules/ExpansionTile.dart';
export 'src/Modules/List.dart';
export 'src/Modules/MxAnimationType.dart';
export 'src/Modules/ProgressLoading.dart';
export 'src/Modules/Route.dart';
export 'src/Modules/SizeTransition.dart';
export 'src/Modules/StoriesBar.dart';
export 'src/Modules/Widget.dart';
export 'src/Modules/title.dart';
export 'src/Swipper/Swipe_To.dart';
export 'src/Text/h_tag.dart';
export 'src/Text/text_material.dart';
export 'src/TextFiled/textFiled_material.dart';
export 'src/Modules/stful_stless.dart';
export 'src/Modules/space.dart';
export 'src/Modules/CardBarButton.dart';
export 'src/Heading/GradientTitle.dart';
export 'src/Heading/heading.dart';
export 'src/Heading/Title.dart';
export 'src/Modules/ImageBlue.dart';
export 'src/Responsive/Responsive_grid.dart';
export 'src/Card/CardTile.dart';
export 'src/Card/CardTiles.dart';
export 'src/Responsive/Extension.dart';
export 'src/Modules/Decoration_Image_Network.dart';
export 'src/Context/Responsive_Context.dart';
export 'src/Context/Responsive_Context.dart';
export 'src/Modules/Decoration_Image_Asset.dart';
export 'src/Modules/Decoration_Image_File.dart';
export 'src/Container/Container_Extesnstion.dart';
export 'src/Extension/Image.dart';
export 'src/Extension/Gesture.dart';
export 'src/Extension/Floating_extend.dart';
export 'src/Extension/SnackBar.dart';
export 'src/Extension/InkWell.dart';
export 'src/Extension/Column.dart';
export 'src/Extension/Row.dart';
export 'src/Extension/Strings.dart';
export 'src/Extension/Widget_String.dart';
export 'src/Extension/Padding.dart';
export 'src/Context/size.dart';
export 'src/Context/Transparent.dart';
export 'src/Modules/TransactioTile.dart';
export 'src/Modules/editor.dart';
export 'src/Modules/BanTile.dart';
export 'src/Extension/Widget.dart';
export 'src/Extension/BlogTile.dart';
export 'src/Extension/Shape.dart';
export 'src/Extension/LinerGradient.dart';
export 'src/Extension/Icon.dart';
export 'src/Extension/Flexable_Responsive.dart';
export 'src/Extension/Color.dart';
export 'src/Extension/function.dart';
export 'src/Extension/GridAnimated.dart';
export 'src/Extension/SilverList.dart';
export 'src/Auto_animated/animate_if_visible.dart';
export 'src/Auto_animated/grid.dart';
export 'src/Auto_animated/helpers/callbacks.dart';
export 'src/Auto_animated/helpers/options.dart';
export 'src/Auto_animated/icon_button.dart';
export 'src/Auto_animated/list.dart';
export 'src/Auto_animated/sliver_grid.dart';
export 'src/Auto_animated/sliver_list.dart';
export 'src/Modules/utils.dart';
export 'src/Extension/Scaffold.dart';
export 'src/Animations/main.dart';
export 'src/Extension/Widgets.dart';
export 'src/Widget/DropDown.dart';
export 'src/Modules/expand.dart';
export 'src/Extension/Tabbar.dart';
export 'src/Extension/Stack.dart';
export 'src/Extension/Stack.dart';
export 'src/Modules/Column.dart';
export 'src/Modules/Row.dart';
export 'src/Modules/ListView.dart';
export 'src/Modules/Stack.dart';
export 'src/Extension/Dropdown.dart';
